{inputs, ...}: {
  imports = with inputs; [
    disko.nixosModules.disko
  ];
  disko.devices.nodev = {
    "/tmp" = {
      fsType = "tmpfs";
      mountOptions = ["rw" "nosuid" "nodev"];
    };
  };
  disko.devices.disk.main = {
    type = "disk";
    device = "/dev/disk/by-id/nvme-eui.000000000000000100a075244b5d6185";
    content = {
      type = "gpt";
      partitions = {
        ESP = {
          size = "2G";
          type = "EF00";
          content = {
            type = "filesystem";
            format = "vfat";
            mountpoint = "/boot";
            mountOptions = [
              "umask=0077"
              "fmask=0022"
              "dmask=0022"
              "noexec"
              "nosuid"
              "nodev"
            ];
          };
        };
        luks = {
          size = "100%";
          content = {
            type = "luks";
            name = "luks-main";
            initrdUnlock = true;
            settings.allowDiscards = true;
            content = {
              type = "btrfs";
              extraArgs = ["-f"];
              subvolumes = {
                "@nixos-root" = {
                  mountpoint = "/";
                  mountOptions = [
                    "compress=zstd"
                    "noatime"
                    "noexec"
                  ];
                };
                "@home" = {
                  mountpoint = "/home";
                  mountOptions = [
                    "compress=zstd"
                    "noatime"
                  ];
                };
                "@storage" = {
                  mountpoint = "/storage";
                  mountOptions = [
                    "compress=zstd"
                    "noatime"
                  ];
                };
                "@nix" = {
                  mountpoint = "/nix";
                  mountOptions = [
                    "compress-force=zstd"
                    "noatime"
                  ];
                };
              };
            };
          };
        };
      };
    };
  };
}
