{inputs, ...}: {
  imports = with inputs; [
    nix-flatpak.homeManagerModules.nix-flatpak
  ];
  services.flatpak = {
    enable = true;
    uninstallUnmanaged = true;
    remotes = [
      {
        name = "flathub";
        location = "https://dl.flathub.org/repo/flathub.flatpakrepo";
      }
      {
        name = "hero-persson";
        location = "https://hero-persson.github.io/unmojang-flatpak/index.flatpakrepo";
      }
    ];
    packages = [
      # misc
      "app.zen_browser.zen"
      "io.github.ungoogled_software.ungoogled_chromium"
      "net.mullvad.MullvadBrowser"
      "com.bitwarden.desktop"
      "com.github.tchx84.Flatseal"
      "com.logseq.Logseq"
      "com.obsproject.Studio"
      "com.usebottles.bottles"
      "de.haeckerfelix.Fragments"
      "org.qbittorrent.qBittorrent"

      # chatting
      "im.riot.Riot"
      "io.github.spacingbat3.webcord"
      "org.mozilla.Thunderbird"
      "org.signal.Signal"
      "org.telegram.desktop"

      # media
      "io.bassi.Amberol"
      "io.freetubeapp.FreeTube"
      # "io.mpv.Mpv"
      #"io.github.celluloid_player.Celluloid"

      # gaming
      #"com.github._0negal.Viper"
      "com.heroicgameslauncher.hgl"
      "net.lutris.Lutris"
      {
        appId = "org.unmojang.FjordLauncher";
        origin = "hero-persson";
      }
      "org.freedesktop.Platform.VulkanLayer.MangoHud//24.08"
      "org.freedesktop.Platform.VulkanLayer.gamescope//24.08"
    ];
    overrides = {
      "global" = {
        # Force Wayland by default
        Context = {
          sockets = ["wayland" "!x11" "!fallback-x11"];
          filesystems = [
            "!home"
            "!host"
            "!~/.ssh"
            "/nix/store:ro"
            "xdg-config/gtk-3.0:ro"
            "xdg-config/gtk-4.0:ro"
            "xdg-run/pipewire-0"
            "~/.local/share/icons:ro"
          ];
        };
        Environment = {
          ELECTRON_OZONE_PLATFORM_HINT = "wayland";
        };
      };
      "org.signal.Signal" = {
        Environment.SIGNAL_PASSWORD_STORE = "gnome-libsecret";
      };
      "com.obsproject.Studio" = {
        Context.filesystems = ["~/vids"];
      };
      "com.logseq.Logseq" = {
        Context.filesystems = [
          "~/docs/logseq"
          "~/docs/nure/2025/logseq"
          "~/syncthing/logseq"
        ];
      };
      "net.lutris.Lutris".Context = {
        sockets = ["x11" "wayland"];
        filesystems = ["/storage/games/lutris" "~/games/lutris"];
      };
      "com.heroicgameslauncher.hgl".Context = {
        sockets = ["x11" "wayland"];
        filesystems = ["/storage/games/heroic" "~/games/heroic"];
      };
      "com.usebottles.Bottles" = {
        Context.sockets = ["x11" "wayland"];
      };
    };
  };
}
